.\" -*-nroff-*-
.\" ====================================================================
.\"  @Troff-man-file{
.\"     author          = "Nelson H. F. Beebe",
.\"     version         = "1.00",
.\"     date            = "07 April 2001",
.\"     time            = "17:54:04 MDT",
.\"     filename        = "pstopng.man",
.\"     address         = "Center for Scientific Computing
.\"                        University of Utah
.\"                        Department of Mathematics, 322 INSCC
.\"                        155 S 1400 E RM 233
.\"                        Salt Lake City, UT 84112-0090
.\"                        USA",
.\"     telephone       = "+1 801 581 5254",
.\"     FAX             = "+1 801 585 1640, +1 801 581 4148",
.\"     URL             = "http://www.math.utah.edu/~beebe",
.\"     checksum        = "59343 317 1161 8489",
.\"     email           = "beebe@math.utah.edu, beebe@acm.org,
.\"                        beebe@computer.org, beebe@ieee.org
.\"                        (Internet)",
.\"     codetable       = "ISO/ASCII",
.\"     keywords        = "PNG (Portable Network Graphics);
.\"                        portable anymap; portable bitmap;
.\"                        PostScript",
.\"     supported       = "yes",
.\"     docstring       = "This is the UNIX manual page document for
.\"                        pstopng.
.\"
.\"                        The checksum field above contains a CRC-16
.\"                        checksum as the first value, followed by the
.\"                        equivalent of the standard UNIX wc (word
.\"                        count) utility output of lines, words, and
.\"                        characters.  This is produced by Robert
.\"                        Solovay's checksum utility.",
.\"  }
.\" ====================================================================
.TH PSTOPNG 1 "07 April 2001" "Version 1.00"
.if t .ds Ps P\s-2OST\s0S\s-2CRIPT\s0
.if n .ds Ps PostScript
.\"======================================================================
.SH NAME
pstopng \- convert (Encapsulated) PostScript files to PNG bitmap files
.\"======================================================================
.SH SYNOPSIS
.B pstopng
[
.B \-?
]
[
.B \-crop
]
[
.B \-debug
]
[
.BI \-extension " name"
]
.if n .ti +8n
[
.BI \-gamma " float-value"
]
[
.B \-help
]
[
.B \-icon
]
.if n .ti +8n
.if t .ti +\w'\fBpstopng\fP\ 'u
[
.BI \-margin " pixels"
]
[
.B \-norun
]
.if n .ti +8n
[
.BI \-resolution " dpi"
]
[
.B \-version
]
.if n .ti +8n
[
.BI \-W "component,option"
]
.if n .ti +8n
.if t .ti +\w'\fBpstopng\fP\ 'u
.I "\*(Ps\&-files"
.\"======================================================================
.SH DESCRIPTION
.B pstopng
converts one or more input
.I "(Encapsulated) \*(Ps\&"
files to output
.I "Portable Network Graphics (PNG)"
lossless compressed bitmap files.
.PP
For maximal color fidelity, bitmaps are produced
in 24-bit color mode, with 16,777,216 possible
colors.
.PP
The PNG format is an Internet Standard defined in
RFC 2083 (1997), and major Web browsers, \&\*(Ps\&
level 3 (1999), and picture editors such as
.BR gimp (1),
.BR photoshop (1),
and
.BR xv (1)
now support it.
.PP
Unlike the Compuserv GIF format, which uses the
Lempel-Ziv-Welch (LZW) compression algorithm
protected under U.S. Patent 4,558,302
(10-Dec-1985) held by Unisys Corporation, PNG is
free of patent and copyright claims, and the PNG
format is recommended for replacement of GIF
images.
.PP
For each file given on the command line, an output
file is written with the same basename as the
input file, but with extension
.IR png ,
or the name specified by the
.B \-extension
option.
.PP
With the
.B \-icon
option, small companion files with the same name
are also written in a subdirectory
.IR icons ,
which is created if necessary.
.PP
If no files are given on the command line, then
.I stdin
is read, and
.I stdout
is written, and no icon file can be produced.
.PP
.B pstopng
is a convenient interface to
.BR gs (1),
.BR pngtopnm (1),
.BR pnmcrop (1),
.BR pnmmargin (1),
and
.BR pnmtopng (1),
which do the real work.
.\"======================================================================
.SH OPTIONS
Command-line options may be abbreviated to a
unique leading prefix.
.PP
To avoid confusion with options, if a filename
begins with a hyphen, it must be disguised by a
leading absolute or relative directory path, e.g.
.I /tmp/-foo.eps
or
.IR ./-foo.eps .
.PP
Options may begin with either UNIX-style single
hyphens, or GNU/POSIX-style double hyphens, and
may be abbreviated to any unique prefix.
.\"-----------------------------------------------
.TP \w'\fB\-gamma\fP\ \fIfloat-value\fP'u+3n
.B \-crop
Crop the image to remove edges that are the
background color.
.\"-----------------------------------------------
.TP
.B \-debug
Turn on debug tracing.
.\"-----------------------------------------------
.TP
.BI \-extension " name"
Replace the default output file extension,
.IR png ,
with
.IR name .
.\"-----------------------------------------------
.TP
.BI \-gamma " float-value"
Specify an image gamma correction as a
floating-point number.  Small values darken the
image, and large values lighten it.  Typical
values are in the range 0.5 .\|. 3.0.
.IP
.RI [Default: " 1.0" ]
.\"-----------------------------------------------
.TP
.B \-?
.br
.ns
.TP
.B \-help
Display a brief help message on
.IR stdout ,
and exit with a success status code (0 on UNIX).
.\"-----------------------------------------------
.TP
.B \-icon
Produce icon files as well as PNG files.  An icon
file is just a low-resolution (12dpi) bitmap that
may be useful as a compact representation of what
is in the PNG file.
.IP
In filter mode (no files on the command line),
this option is ignored.
.\"-----------------------------------------------
.TP
.BI \-margin " pixels"
Add a background margin of width
.I pixels
to the output image.  This option is usually
specified together with
.BR \-crop .
.\"-----------------------------------------------
.TP
.B \-norun
Show on
.I stdout
the commands that would be executed, but do not
run them.
.IP
Use this option to trap the complex command
pipelines for further private customization.
.\"-----------------------------------------------
.TP
.BI \-resolution " dpi"
Set the output bitmap resolution to
.I dpi
dots per inch.
.IP
.RI [Default: " 100" " dpi, suitable only for screen resolution]."
.\"-----------------------------------------------
.TP
.B \-version
Display program version numbers and dates on
.IR stdout ,
and exit with a success status code (0 on UNIX).
.\"-----------------------------------------------
.TP
.BI \-W "component,option"
Pass
.I option
to the program
.IR component ,
which must be one of
.IR gs ,
.IR pngtopnm ,
.IR pnmcrop ,
.IR pnmmargin ,
or
.IR pnmtopng .
.IP
This option, a POSIX convention, provides a
general way for a user to pass options to programs
invoked by another program.  The value
.I option
is passed
.I after
any generated in response to options supplied to
.BR pstopng .
For example,
.BI \-W pnmmargin,-black
would cause any added margin to be colored black.
.\"======================================================================
.SH "SEE ALSO"
.BR epsutil (1),
.BR gimp (1),
.BR gs (1),
.BR photoshop (1),
.BR pngtopnm (1),
.BR pnmcrop (1),
.BR pnmmargin (1),
.BR pnmtopng (1),
.BR pstojpeg (1),
.BR pstotiff (1),
.BR xv (1).
.PP
T. Boutell,
.IR "RFC 2083: PNG (Portable Network Graphics) Specification Version 1.0" ,
available at \&\fCftp://ftp.internic.net/rfc/rfc2083.txt\fP.
.PP
John Miano,
.IR "The programmer's guide to compressed image files: JPEG, PNG, GIF, XBM, BMP" ,
Addison-Wesley Longman,
Harlow, Essex, England 1999,
ISBN 0-201-60443-4.
.PP
Greg Roelofs,
.IR "PNG: The Definitive Guide" ,
O'Reilly and Associates, Inc., Sebastopol, CA,
Cambridge, MA, and Beijing, China, 1999, ISBN
1-56592-542-4.
.\"======================================================================
.SH AUTHOR
.nf
Nelson H. F. Beebe, Ph.D.
Center for Scientific Computing
University of Utah
Department of Mathematics, 322 INSCC
155 S 1400 E RM 233
Salt Lake City, UT 84112-0090
Tel: +1 801 581 5254
FAX: +1 801 585 1640, +1 801 581 4148
Email: \fCbeebe@math.utah.edu\fP, \fCbeebe@acm.org\fP,
       \fCbeebe@computer.org\fP, \fCbeebe@ieee.org\fP
WWW URL: \fChttp://www.math.utah.edu/~beebe\fP
.fi
.\"==============================[The End]==============================
.\" This is for GNU Emacs file-specific customization:
.\" Local Variables:
.\" fill-column: 50
.\" End:
